from RocketCasing import RocketCasing

RocketCasing.casing()